@@ -1,7 +1,8 @@
 from __future__ import absolute_import
 
 from .block import Division
-from .element import (Element, html_attribute, boolean_html_attribute,
+from .element import (Element, ShortElement,
+                      html_attribute, boolean_html_attribute,
                       int_html_attribute)
 from .generator import (Generator, NullGenerator, ChildGenerator,
                         HTMLChildGenerator, JoinGenerator, HTMLJoinGenerator)
